from edc_test_settings.func_main import func_main2

if __name__ == "__main__":
    func_main2(
        "tests.test_settings",
        "tests",
        "meta_ae.tests",
        "meta_consent.tests",
        "meta_dashboard.tests",
        "meta_edc.tests",
        "meta_labs.tests",
        "meta_lists.tests",
        "meta_prn.tests",
        "meta_rando.tests",
        "meta_screening.tests",
        "meta_subject.tests",
        "meta_visit_schedule.tests",
    )
