# Generated by Django 4.2.11 on 2024-06-06 19:15

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="UnattendedThreeInRow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                ("appt_datetime", models.DateTimeField()),
                ("first", models.CharField(max_length=25)),
                ("second", models.CharField(max_length=25)),
                ("third", models.CharField(max_length=25)),
                ("interval_days", models.IntegerField()),
                ("from_now_days", models.IntegerField()),
                ("created", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Unattended: Three in a row",
                "verbose_name_plural": "Unattended: Three in a row",
                "db_table": "unattended_three_in_row_view",
                "managed": False,
            },
        ),
        migrations.CreateModel(
            name="UnattendedThreeInRow2",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                ("first", models.CharField(max_length=25)),
                ("second", models.CharField(max_length=25)),
                ("third", models.CharField(max_length=25)),
                ("interval_days", models.IntegerField()),
                ("from_now_days", models.IntegerField()),
                ("missed_count", models.IntegerField()),
                ("created", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Unattended: Three in a row (with missed)",
                "verbose_name_plural": "Unattended: Three in a row (with missed)",
                "db_table": "unattended_three_in_row2_view",
                "managed": False,
            },
        ),
        migrations.CreateModel(
            name="UnattendedTwoInRow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                ("appt_datetime", models.DateTimeField()),
                ("first", models.CharField(max_length=25)),
                ("second", models.CharField(max_length=25)),
                ("interval_days", models.IntegerField()),
                ("from_now_days", models.IntegerField()),
                ("created", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Unattended: Two in a row",
                "verbose_name_plural": "Unattended: Two in a row",
                "db_table": "unattended_two_in_row_view",
                "managed": False,
            },
        ),
    ]
