# Generated by Django 3.2.6 on 2021-08-17 20:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0080_auto_20210812_0400"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmnsi",
            name="amputation",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an amputation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ankle_reflexes_left_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ankle_reflexes_right_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="burning_pain_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any burning pain in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="covers_touch_skin_painful",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Does it hurt when the bed covers touch your skin?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="diabetic_neuropathy",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has your doctor ever told you that you have diabetic neuropathy?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="differentiate_hot_cold_water",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="When you get into the tub or shower, are you able to tell the hot water from the cold water?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="examined_left_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the LEFT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="examined_right_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the RIGHT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="feel_weak",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you feel weak all over most of the time?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="feet_sensitive_touch",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your feet too sensitive to touch?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="legs_hurt_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do your legs hurt when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="mnsi_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Is the MNSI assessment being performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="monofilament_left_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="monofilament_right_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="muscle_cramps_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you get muscle cramps in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="normal_appearance_left_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does LEFT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="normal_appearance_right_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does RIGHT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="numb_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your legs and/or feet numb?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="open_sore_foot_history",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an open sore on your foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="prickling_feelings_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any prickling feelings in your legs or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="sense_feet_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are you able to sense your feet when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="skin_cracks_open_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the skin on your feet so dry that it cracks open?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="symptoms_worse_night",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your symptoms worse at night?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ulceration_left_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ulceration_right_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="vibration_perception_left_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="vibration_perception_right_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="amputation",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an amputation?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ankle_reflexes_left_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ankle_reflexes_right_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="burning_pain_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any burning pain in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="covers_touch_skin_painful",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Does it hurt when the bed covers touch your skin?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="diabetic_neuropathy",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has your doctor ever told you that you have diabetic neuropathy?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="differentiate_hot_cold_water",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="When you get into the tub or shower, are you able to tell the hot water from the cold water?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="examined_left_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the LEFT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="examined_right_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the RIGHT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="feel_weak",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you feel weak all over most of the time?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="feet_sensitive_touch",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your feet too sensitive to touch?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="legs_hurt_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do your legs hurt when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="mnsi_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Is the MNSI assessment being performed?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="monofilament_left_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="monofilament_right_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="muscle_cramps_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you get muscle cramps in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="normal_appearance_left_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does LEFT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="normal_appearance_right_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does RIGHT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="numb_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your legs and/or feet numb?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="open_sore_foot_history",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an open sore on your foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="prickling_feelings_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any prickling feelings in your legs or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="sense_feet_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are you able to sense your feet when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="skin_cracks_open_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the skin on your feet so dry that it cracks open?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="symptoms_worse_night",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your symptoms worse at night?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ulceration_left_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ulceration_right_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="vibration_perception_left_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="vibration_perception_right_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, RIGHT foot?",
            ),
        ),
    ]
