# Generated by Django 4.2.11 on 2024-06-18 02:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0002_patienthistorymissingbaselinecd4_and_more"),
    ]

    operations = []
