# Generated by Django 3.0.4 on 2020-04-20 12:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0025_auto_20200420_1455"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="coronakap",
            options={
                "verbose_name": "Coronavirus Knowledge, Attitudes, and Practices",
                "verbose_name_plural": "Coronavirus Knowledge, Attitudes, and Practices",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalcoronakap",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Coronavirus Knowledge, Attitudes, and Practices",
            },
        ),
        migrations.AddIndex(
            model_name="coronakap",
            index=models.Index(
                fields=["subject_visit", "site", "id"],
                name="meta_subjec_subject_4bc9e9_idx",
            ),
        ),
    ]
