# Generated by Django 4.2.5 on 2023-10-17 22:25

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0014_auto_20220913_2139"),
    ]

    operations = [
        migrations.AddField(
            model_name="abnormalfootappearanceobservations",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="arvregimens",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="baselinesymptoms",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="diabetessymptoms",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="hypertensionmedications",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="nonadherencereasons",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="offstudyreasons",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="oiprophylaxis",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="subjectvisitmissedreasons",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="symptoms",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="transferreasons",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
    ]
