# Generated by Django 5.0 on 2024-01-09 23:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_rando", "0004_alter_randomizationlist_options_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="randomizationlist",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "permissions": (("display_assignment", "Can display assignment"),),
                "verbose_name": "Randomization List (Phase Three)",
                "verbose_name_plural": "Randomization List (Phase Three)",
            },
        ),
        migrations.AlterUniqueTogether(
            name="randomizationlist",
            unique_together=set(),
        ),
        migrations.AddField(
            model_name="historicalrandomizationlist",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalrandomizationlist",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="randomizationlist",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="randomizationlist",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddIndex(
            model_name="randomizationlist",
            index=models.Index(
                fields=["modified", "created"], name="meta_rando__modifie_135549_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="randomizationlist",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="meta_rando__user_mo_c334b9_idx",
            ),
        ),
        migrations.AddConstraint(
            model_name="randomizationlist",
            constraint=models.UniqueConstraint(
                fields=("site_name", "sid"),
                name="meta_rando_randomizationlist_site_sid_uniq",
            ),
        ),
    ]
