# Generated by Django 3.0.6 on 2020-05-27 23:52
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0041_auto_20200528_0242"),
    ]

    operations = []
