# Generated by Django 4.2.11 on 2024-07-31 01:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0008_alter_endpoints_endpoint_label"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="endpoints",
            options={
                "default_permissions": ("view", "export", "viewallsites"),
                "verbose_name": "Endpoints (DM)",
                "verbose_name_plural": "Endpoints (DM)",
            },
        ),
    ]
