# Generated by Django 4.2.11 on 2024-07-27 00:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0005_endpoints"),
    ]

    operations = [
        migrations.AddField(
            model_name="endpoints",
            name="baseline_datetime",
            field=models.DateTimeField(null=True),
        ),
    ]
