{% extends 'edc_subject_dashboard/bootstrap3/dashboard.html' %}

{% load static %}

{% block locator_information %}{% endblock locator_information %}

{% block top_bar %}

    {% include "meta_dashboard/bootstrap3/subject/dashboard/top_bar.html" %}

{% endblock top_bar %}
